.. _utilipy-utils-functools:

*************************************
Functools (`utilipy.utils.functools`)
*************************************

.. currentmodule:: utilipy.utils.functools


Reference/API
=============

.. automodapi:: utilipy.utils.functools
	:allowed-package-names: functools
